@@ -793,15 +793,19 @@ class GeometryCollection(_Feature):
         gifs = []
         for geom in self._geoms:
             gifs.append(geom.__geo_interface__)
-        return {'type': self._type, 'geometries': gifs }
+        return {'type': self._type, 'geometries': tuple(gifs) }
 
     def __init__(self, features):
         self._geoms = []
         if isinstance(features, (list, tuple)):
             for feature in features:
-                if isinstance(feature, (Point, LineString, LinearRing, Polygon)):
+                if isinstance(feature,
+                        (Point, LineString, LinearRing, Polygon,
+                        MultiPoint, MultiLineString, MultiPolygon)):
                     self._geoms.append(feature)
-                elif isinstance(as_shape(feature), (Point, LineString, LinearRing, Polygon)):
+                elif isinstance(as_shape(feature),
+                        (Point, LineString, LinearRing, Polygon,
+                        MultiPoint, MultiLineString, MultiPolygon)):
                     self._geoms.append(as_shape(feature))
                 else:
                     raise ValueError
@@ -811,7 +815,8 @@ class GeometryCollection(_Feature):
     @property
     def geoms(self):
         for geom in self._geoms:
-            if isinstance(geom, (Point, LineString, LinearRing, Polygon)):
+            if isinstance(geom, (Point, LineString, LinearRing, Polygon,
+                                MultiPoint, MultiLineString, MultiPolygon)):
                 yield geom
             else:
                 raise ValueError("Illegal geometry type.")
