@@ -278,7 +278,9 @@ class BasicTestCase(unittest.TestCase):
         self.assertEqual(gc.__geo_interface__,gc1.__geo_interface__)
         self.assertRaises(NotImplementedError, geometry.GeometryCollection, [p,f])
         mp1 = geometry.MultiPoint([p0, p1])
-        self.assertRaises(ValueError, geometry.GeometryCollection, [p,mp1])
+        # geometry collection can contain multigeometries
+        gc2 = geometry.GeometryCollection([p,mp1])
+        self.assertEqual(list(gc2.geoms)[1], mp1)
 
 
 
